diff --git a/nuxt4/app/components/cata/ModalAsignacionRapida.vue b/nuxt4/app/components/cata/ModalAsignacionRapida.vue
index c74a389..b0f53cb 100644
--- a/nuxt4/app/components/cata/ModalAsignacionRapida.vue
+++ b/nuxt4/app/components/cata/ModalAsignacionRapida.vue
@@ -26,9 +26,9 @@
@@ -154,21 +154,21 @@ const isOpen = computed({
// Estado del formulario
const paso = ref(1)
-const puntajeDeseado = ref(40)
+const puntajeDeseado = ref(45)
const categoriasSeleccionadas = ref([])
// Resetear estado cuando el modal se abre
watch(isOpen, (newValue) => {
if (newValue) {
paso.value = 1
- puntajeDeseado.value = 40
+ puntajeDeseado.value = 45
categoriasSeleccionadas.value = []
}
})
// Cálculos
const puntajeValido = computed(() => {
- return puntajeDeseado.value >= 8 && puntajeDeseado.value <= 80
+ return puntajeDeseado.value >= 9 && puntajeDeseado.value <= 90
})
const multiploMasCercano = computed(() => {
diff --git a/nuxt4/app/components/cata/SelectorFamilia.vue b/nuxt4/app/components/cata/SelectorFamilia.vue
index 7a4f6d7..de4bbc0 100644
--- a/nuxt4/app/components/cata/SelectorFamilia.vue
+++ b/nuxt4/app/components/cata/SelectorFamilia.vue
@@ -34,7 +34,7 @@
@@ -62,7 +62,7 @@
{{ subcategoria }}
diff --git a/nuxt4/app/components/cata/SelectorIntensidad.vue b/nuxt4/app/components/cata/SelectorIntensidad.vue
index 1a0fbef..a7acf57 100644
--- a/nuxt4/app/components/cata/SelectorIntensidad.vue
+++ b/nuxt4/app/components/cata/SelectorIntensidad.vue
@@ -47,7 +47,7 @@
diff --git a/nuxt4/app/components/cata/FormularioMuestra.vue b/nuxt4/app/components/cata/FormularioMuestra.vue
index 5164c97..f0a60ec 100644
--- a/nuxt4/app/components/cata/FormularioMuestra.vue
+++ b/nuxt4/app/components/cata/FormularioMuestra.vue
@@ -809,7 +809,7 @@
{{ muestra.puntajeFinal }}
- Suma de valores descriptivos
+ Suma de valores afectivos
@@ -955,9 +955,9 @@ const modalAsignacionRapida = ref(false)
// Aplicar asignación rápida de puntajes
const aplicarAsignacionRapida = async (puntajes: Record) => {
// Aplicar cada puntaje a su categoría correspondiente
for (const [categoria, puntaje] of Object.entries(puntajes)) {
- await actualizarIntensidad(categoria as keyof Muestra['intensidades'], 'descriptiva', puntaje)
+ await actualizarIntensidad(categoria as keyof Muestra['intensidades'], 'afectiva', puntaje)
}
}
@@ -955,9 +955,9 @@ const modalAsignacionRapida = ref(false)
// Aplicar asignación rápida de puntajes
const aplicarAsignacionRapida = async (puntajes: Record) => {
- // Aplicar cada puntaje a su categoría correspondiente
+ // Aplicar cada puntaje a su categoría correspondiente (afectiva)
for (const [categoria, puntaje] of Object.entries(puntajes)) {